==> seedsui-react-5.7.17.tgz: package/lib/DatePicker/utils/getRanges.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import locale from "./../../locale";

// ranges分成两部分: quickRanges(快捷选择)和customRanges(自定义选择)
function getRanges(ranges) {
  var quickRanges = {};
  var customRanges = {};
  if (toString.call(ranges) === '[object Object]' && !Object.isEmptyObject(ranges)) {
    for (var rangeKey in ranges) {
      var rangeValue = ranges[rangeKey];
      if (Array.isArray(rangeValue) && rangeValue.length === 2 && rangeValue[0] instanceof Date && rangeValue[1] instanceof Date) {
        quickRanges[rangeKey] = rangeValue;
      } else {
        // 自定义选择只能有一个
        customRanges = _defineProperty({}, rangeKey, rangeValue);
      }
    }
  } else {
    if (typeof ranges === 'number') {
      customRanges = _defineProperty({}, locale('自定义时间', 'datepicker-tooltip_custom_date'), ranges);
    }
  }
  return {
    quickRanges: quickRanges,
    customRanges: customRanges
  };
}
export default getRanges;

==> seedsui-react-5.7.43.tgz: package/lib/DatePicker/utils/getRanges.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import locale from "./../../locale";

// ranges分成两部分: quickRanges(快捷选择)和customRanges(自定义选择)
function getRanges(ranges) {
  var quickRanges = {};
  var customRanges = {};
  if (toString.call(ranges) === '[object Object]' && !Object.isEmptyObject(ranges)) {
    for (var rangeKey in ranges) {
      var rangeValue = ranges[rangeKey];
      if (Array.isArray(rangeValue) && rangeValue.length === 2 && Object.isDate(rangeValue[0]) && Object.isDate(rangeValue[1])) {
        quickRanges[rangeKey] = rangeValue;
      } else {
        // 自定义选择只能有一个
        customRanges = _defineProperty({}, rangeKey, rangeValue);
      }
    }
  } else {
    if (typeof ranges === 'number') {
      customRanges = _defineProperty({}, locale('自定义时间', 'datepicker-tooltip_custom_date'), ranges);
    }
  }
  return {
    quickRanges: quickRanges,
    customRanges: customRanges
  };
}
export default getRanges;
